********************************************************************
* 'The politics of double-delegation in EU aid'
* Replication file 
* ISQ 2017-04-0201
********************************************************************

  use ISQ-2017-04-0201, clear
  
* Sets of variables

  global Ctrl  lnlife frag lngdppc doda year tParis
  global Ctrl2 lnlife frag lngdppc doda year 
  
  global AAL lexportEUshare 
  global PA  cova_it covastbyi
  global CAP acp2 enp2 commlang lnecops wb_del 
  g wbtotp=ln(1+wbtot/xrecyear)
  lab var wbtotp "WB amount" 
  global CAP3 $CAP wbtotp
    
  
* Coupled stages through CMP (year>=2000)
* ******************************************************************
 
  replace prj0=. if year<2000
  replace cty0=. if year<2000

  cmp setup 
  * If cmp not installed: via STATA help search "cmp package",
  * install cmp from http://fmwww.bc.edu/RePEc/bocode/c
  set matsize 800
  
g cimp1=(important1>0)
g simp1=(simportant1>0)
lab var simp1 "Important sector"

  ** Country-earmarking

  qui cmp (mai_avg=$AAL $CAP cova_it $Ctrl) (cty0=$AAL $CAP cova_it $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  * If ghk2 not installed: via STATA help search "ghk2 package", 
  * install ghk2 from  http://fmwww.bc.edu/repec/bocode/g
  est store cmp11
  
  qui cmp (mai_avg=$AAL $CAP3 cova_it $Ctrl) (cty0=$AAL $CAP3 cova_it $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp12
  
  qui cmp (mai_avg=simp1 $AAL $CAP cova_it $Ctrl) (cty0=simp1 $AAL $CAP3 cova_it $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp13

  ** Project-earmarking

  qui cmp (mai_avg=$AAL $CAP covastbyi $Ctrl) (prj0=$AAL $CAP covastbyi $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp14
  
  qui cmp (mai_avg=$AAL $CAP3 covastbyi $Ctrl) (prj0=$AAL $CAP3 covastbyi $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp15
  
  qui cmp (mai_avg=simp1 $AAL $CAP covastbyi $Ctrl) (prj0=simp1 $AAL $CAP3 covastbyi $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp16
  
** Table 1 **
#delimit ;

esttab cmp1* using "Table 1.rtf", replace modelwidth(6) addnote("Double delegation equation of SUR system. Recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("") keep(mai_avg:) drop(_cons) order(acp2 enp2 commlang lnecops wb_del wbtotp simp1 lexportEUshare lnlife lngdppc frag cova_it covastbyi doda year tParis)
legend cells(b(star fmt(3)) se(par)) stats(N1 N2 N_clust chi2, fmt(%7.0f %7.0f %7.0f %7.2f) labels("First-stage observations" "Second-stage observations" "Recipient countries" "Chi-squared")) 
label varwidth(27) collabels(none);

#delimit cr   

  mat Rsq=J(2,6,0)
  qui reg mai_avg $AAL $CAP cova_it $Ctrl if year>=2000
  mat Rsq[1,1]=e(r2)
  qui reg cty0 $AAL $CAP3 cova_it $Ctrl2 if year>=2000
  mat Rsq[2,1]=e(r2)
  qui reg mai_avg $AAL $CAP cova_it $Ctrl if year>=2000
  mat Rsq[1,2]=e(r2)
  qui reg cty0 $AAL $CAP3 cova_it $Ctrl2 if year>=2000
  mat Rsq[2,2]=e(r2)
  qui reg mai_avg simp1 $AAL $CAP cova_it $Ctrl if year>=2000
  mat Rsq[1,3]=e(r2)
  qui reg cty0 simp1 $AAL $CAP cova_it $Ctrl2 if year>=2000
  mat Rsq[2,3]=e(r2)
  qui reg mai_avg $AAL $CAP covastbyi $Ctrl if year>=2000
  mat Rsq[1,4]=e(r2)
  qui reg prj0 $AAL $CAP covastbyi $Ctrl2 if year>=2000
  mat Rsq[2,4]=e(r2)
  qui reg mai_avg $AAL $CAP3 covastbyi $Ctrl if year>=2000
  mat Rsq[1,5]=e(r2)
  qui reg prj0 $AAL $CAP3 covastbyi $Ctrl2 if year>=2000
  mat Rsq[2,5]=e(r2)
  qui reg mai_avg simp1 $AAL $CAP covastbyi $Ctrl if year>=2000
  mat Rsq[1,6]=e(r2)
  qui reg prj0 simp1 $AAL $CAP covastbyi $Ctrl2 if year>=2000
  mat Rsq[2,6]=e(r2)
  mat li Rsq

** Table 2 **
#delimit ;

esttab cmp1* using "Table 2.rtf", replace modelwidth(6) addnote("Earmarking equation of SUR system. Recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("") keep(cty0: prj0:) drop(_cons) order(acp2 enp2 commlang lnecops wb_del wbtotp simp1 lexportEUshare lnlife lngdppc frag cova_it covastbyi doda year)
legend cells(b(star fmt(3)) se(par)) stats(N1 N2 N_clust chi2, fmt(%7.0f %7.0f %7.0f %7.2f) labels("First-stage observations" "Second-stage observations" "Recipient countries" "Chi-squared")) 
label varwidth(27) collabels(none);

#delimit cr   
   
  
* *****************************************************************************  
* Appendix
* *****************************************************************************

* Descriptives
* ************

** Table A1 ** 
  estpost summarize mai_avg prj0 cty0 $AAL cova_it covastbyi $CAP lnwbtot wbtotp simp1 lngdppc lnlife frag doda ecops year tParis if year>=2000
  esttab using "Table A1.rtf", cells("count mean sd min max") noobs replace label   

  estpost summarize mai_avg prj0 cty0 $AAL cova_it covastbyi $CAP lnwbtot wbtotp simp1 lngdppc lnlife frag doda ecops year tParis 
  esttab , cells("count mean sd min max") noobs replace label   


* Separate stages
* ***************

* Stage 1 
  
  qui xtreg mai_avg $AAL $CAP cova_it $Ctrl if year>=2000, cl(reccode)
  est store re11
  
  qui xtreg mai_avg $AAL $CAP3 cova_it $Ctrl if year>=2000, cl(reccode)
  est store re12
  
  qui xtreg mai_avg simp1 $AAL $CAP cova_it $Ctrl if year>=2000, cl(reccode)
  est store re13
  
  qui xtreg mai_avg $AAL $CAP covastbyi $Ctrl if year>=2000, cl(reccode)
  est store rer11
  
  qui xtreg mai_avg $AAL $CAP3 covastbyi $Ctrl if year>=2000, cl(reccode)
  est store rer12
  
  qui xtreg mai_avg simp1 $AAL $CAP covastbyi $Ctrl if year>=2000, cl(reccode)
  est store rer13
  
** Table A3 **  
#delimit ;

esttab re1* rer1* using "Table A3.rtf", replace modelwidth(7) addnote("Random-effect estimation with recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("") drop(_cons _*) order(acp2 enp2 commlang lnecops wb_del wbtotp simp1 lexportEUshare lnlife lngdppc frag cova_it covastbyi doda year tParis)
legend cells(b(star fmt(3)) se(par)) stats(N r2_o N_clust, fmt(%7.0f %7.2f %7.0f) labels("Observations" "Overall R2" "Chi2")) 
label varwidth(28) collabels(none);

#delimit cr    
  
* Panel diagnostics for first stage
  qui xtreg mai_avg $AAL $CAP3 cova_it $Ctrl if year>=2000, fe
  est store CONSIST
  qui xtreg mai_avg $AAL $CAP3 cova_it $Ctrl if year>=2000, re
  est store EFFIC
  hausman CONSIST EFFIC

* Stage 2

  ** Country-earmarking - matched with country-heterogeneity
  qui xtreg cty0 $AAL $CAP cova_it $Ctrl2 if year>=2000, cl(reccode)
  est store em1
  
  qui xtreg cty0 $AAL $CAP3 cova_it $Ctrl2 if year>=2000, cl(reccode)
  est store em2

  qui xtreg cty0 simp1 $AAL $CAP cova_it $Ctrl2 if year>=2000, cl(reccode)
  est store em3
  
  ** Sector-earmarking - matched with sector-heterogeneity at country level
  qui xtreg prj0 $AAL $CAP covastbyi $Ctrl2 if year>=2000, cl(reccode)
  est store em4
  
  qui xtreg prj0 $AAL $CAP3 covastbyi $Ctrl2 if year>=2000, cl(reccode)
  est store em5
  
  qui xtreg prj0 simp1 $AAL $CAP covastbyi $Ctrl2 if year>=2000, cl(reccode)
  est store em6
  
** Table A4 **  
#delimit ;

esttab em* using "Table A4.rtf", replace modelwidth(6) addnote("Random-effects estimation with recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("") order(acp2 enp2 commlang lnecops wb_del wbtotp simp1 lexportEUshare lnlife lngdppc frag cova_it covastbyi doda year tParis) keep(simp1 $AAL $CAP3 cova_it covastbyi $Ctrl2)
legend cells(b(star fmt(3)) se(par)) stats(N r2_o N_clust, fmt(%7.0f %7.2f %7.0f) labels("Observations" "Overall R2" "Chi2")) 
label varwidth(27) collabels(none);

#delimit cr   
  


* Additional interactions
* ***********************

global all3 lexportEUshare exportcova commlang commcova acp2 acpcova enp2 enpcova wb_del 

  ** Geographic earmarking
  replace acpcova=acp2*cova_it
  replace enpcova=enp2*cova_it
  replace exportcova=lexportEU*cova_it
  replace commcova=commlang*cova_it
 
  qui cmp (mai_avg=cova_it $all3 $Ctrl) (cty0=cova_it $all3 $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp21
  
  qui xtreg mai_avg cova_it $all3 $Ctrl if year>=2000, cl(reccode)
  est store add11
  
  qui xtreg cty0 cova_it $all3 $Ctrl2 if year>=2000, cl(reccode)
  est store add21
 
  ** Sector earmarking
  replace acpcova=acp2*covastbyi
  replace enpcova=enp2*covastbyi
  replace exportcova=lexportEU*covastbyi
  replace commcova=commlang*covastbyi
  
  qui cmp (mai_avg=covastbyi $all3 $Ctrl) (prj0=covastbyi $all3 $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmp22
  
  qui xtreg mai_avg covastbyi $all3 $Ctrl if year>=2000, cl(reccode)
  est store add12
  
  qui xtreg prj0 covastbyi $all3 $Ctrl2 if year>=2000, cl(reccode)
  est store add22  

** Table A5 **
#delimit ;

esttab cmp21 add11 cmp22 add12 using "Table A5.rtf", replace modelwidth(6) addnote("First-stage models with additional interactions. Recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("") keep(main:) drop(_cons) order(acp* enp* comm* wb_del cova_it covastbyi $all3 $Ctrl)
legend cells(b(star fmt(3)) se(par)) stats(N1 N2 N_clust chi2, fmt(%7.0f %7.0f %7.0f %7.2f) labels("First-stage observations" "Second-stage observations" "Recipient countries" "Chi-squared")) 
label varwidth(27) collabels(none);

#delimit cr   

  mat Rsq=J(2,4,0)
  qui reg mai_avg cova_it $all3 $Ctrl if year>=2000
  mat Rsq[1,1]=e(r2)
  qui reg cty0 cova_it $all3 $Ctrl2 if year>=2000
  mat Rsq[2,1]=e(r2)
  qui reg mai_avg cova_it $all3 $Ctrl if year>=2000
  mat Rsq[1,2]=e(r2)
  qui reg cty0 cova_it $all3 $Ctrl2 if year>=2000
  mat Rsq[2,2]=e(r2)
  qui reg mai_avg covastbyi $all3 $Ctrl if year>=2000
  mat Rsq[1,3]=e(r2)
  qui reg prj0 $all3 covastbyi $Ctrl2 if year>=2000
  mat Rsq[2,3]=e(r2)
  qui reg mai_avg $all3 covastbyi $Ctrl if year>=2000
  mat Rsq[1,4]=e(r2)
  qui reg prj0 $all3 covastbyi $Ctrl2 if year>=2000
  mat Rsq[2,4]=e(r2)
  mat li Rsq


** Table A6 ** (two CMP columns)
#delimit ;

esttab cmp21 add21 cmp22 add22 using "Table A6.rtf", replace modelwidth(6) addnote("First-stage models with additional interactions. Recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("")  drop(_cons main:) order(acp* enp* comm* wb_del cova_it covastbyi $all3 $Ctrl2)
legend cells(b(star fmt(3)) se(par)) stats(N1 N2 N_clust chi2, fmt(%7.0f %7.0f %7.0f %7.2f) labels("First-stage observations" "Second-stage observations" "Recipient countries" "Chi-squared")) 
label varwidth(27) collabels(none);

#delimit cr   
  
  ** Table A6 continued (two RE columns) **
  
#delimit ;

esttab add21 add22, modelwidth(6) addnote("First-stage models with additional interactions. Recipient-clustered standard errors in parentheses") 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("")  drop(_cons) order(acp* enp* comm* wb_del lexport* $Ctrl2 cova_it covastbyi )
legend cells(b(star fmt(3)) se(par)) stats(N1 N2 N_clust chi2, fmt(%7.0f %7.0f %7.0f %7.2f) labels("First-stage observations" "Second-stage observations" "Recipient countries" "Chi-squared")) 
label varwidth(27) collabels(none);

#delimit cr   


* Importance-induced capacity gap (cimp1)
* *******************************************************

  ** Country-earmarking

  qui cmp (mai_avg=cimp1 $AAL $CAP cova_it $Ctrl) (cty0=cimp1 $AAL $CAP cova_it $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmpb911
  
  ** Project-earmarking

  qui cmp (mai_avg=cimp1 $AAL $CAP covastbyi $Ctrl) (prj0=cimp1 $AAL $CAP covastbyi $Ctrl2) if year>=2000, indicators($cmp_cont $cmp_cont) ro cl(reccode) 
  est store cmpb912
  
** Table A7 **
  #delimit ;

esttab cmpb91* using "Table A7.rtf", replace modelwidth(6) addnote("Double delegation equation of SUR system. Recipient-clustered standard errors in parentheses") unstack 
 starlevels(* 0.10 ** 0.05 *** 0.01) mlab("") keep() drop(_cons) order($CAP cimp1 $AAL cova_it covastbyi $Ctrl)
legend cells(b(star fmt(3)) se(par)) stats(N1 N2 N_clust chi2, fmt(%7.0f %7.0f %7.0f %7.2f) labels("First-stage observations" "Second-stage observations" "Recipient countries" "Chi-squared")) 
label varwidth(27) collabels(none);

#delimit cr   
 
  mat Rsq=J(1,4,0)
  qui reg mai_avg cimp1 $AAL $CAP cova_it $Ctrl if year>=2000
  mat Rsq[1,1]=e(r2)
  qui reg cty0 cimp1 $AAL $CAP cova_it $Ctrl2  if year>=2000
  mat Rsq[1,2]=e(r2)
  qui reg mai_avg cimp1 $AAL $CAP covastbyi $Ctrl if year>=2000
  mat Rsq[1,3]=e(r2)
  qui reg prj0 cimp1 $AAL $CAP covastbyi $Ctrl2  if year>=2000
  mat Rsq[1,4]=e(r2)
  mat li Rsq

  
*************************************
